@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "16.0.1+9-24" },
-            { "jdk", "16.0.1" },
-            { "release", "16.0.1" },
+            { "full", "17.0.5+8" },
+            { "jdk", "17.0.5" },
+            { "release", "17.0.5" },
         };
     }
 }
