@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -197,7 +193,6 @@ public class LocaleNames_zgh extends OpenListResourceBundle {
             { "ME", "\u2d4e\u2d53\u2d4f\u2d5c\u2d49\u2d4f\u2d49\u2d33\u2d54\u2d53" },
             { "MG", "\u2d4e\u2d30\u2d37\u2d30\u2d56\u2d30\u2d5b\u2d47\u2d30\u2d54" },
             { "MH", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d4e\u2d30\u2d54\u2d5b\u2d30\u2d4d" },
-            { "MK", "\u2d4e\u2d30\u2d59\u2d49\u2d37\u2d53\u2d4f\u2d62\u2d30" },
             { "ML", "\u2d4e\u2d30\u2d4d\u2d49" },
             { "MM", "\u2d4e\u2d62\u2d30\u2d4f\u2d4e\u2d30\u2d54" },
             { "MN", "\u2d4e\u2d4f\u2d56\u2d53\u2d4d\u2d62\u2d30" },
